==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/FhirServiceCorsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The settings for the CORS configuration of the service instance.
 * @property allowCredentials If credentials are allowed via CORS.
 * @property headers The headers to be allowed via CORS.
 * @property maxAge The max age to be allowed via CORS.
 * @property methods The methods to be allowed via CORS.
 * @property origins The origins to be allowed via CORS.
 */
public data class FhirServiceCorsConfigurationArgs(
    public val allowCredentials: Output<Boolean>? = null,
    public val headers: Output<List<String>>? = null,
    public val maxAge: Output<Int>? = null,
    public val methods: Output<List<String>>? = null,
    public val origins: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs.builder()
            .allowCredentials(allowCredentials?.applyValue({ args0 -> args0 }))
            .headers(headers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .maxAge(maxAge?.applyValue({ args0 -> args0 }))
            .methods(methods?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .origins(origins?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FhirServiceCorsConfigurationArgs].
 */
@PulumiTagMarker
public class FhirServiceCorsConfigurationArgsBuilder internal constructor() {
    private var allowCredentials: Output<Boolean>? = null

    private var headers: Output<List<String>>? = null

    private var maxAge: Output<Int>? = null

    private var methods: Output<List<String>>? = null

    private var origins: Output<List<String>>? = null

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("uyqfbhbjqibhtbmw")
    public suspend fun allowCredentials(`value`: Output<Boolean>) {
        this.allowCredentials = value
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("rttllqcgnhkffkac")
    public suspend fun headers(`value`: Output<List<String>>) {
        this.headers = value
    }

    @JvmName("xilyqueucnujobdl")
    public suspend fun headers(vararg values: Output<String>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("dsfyqtjxypblcvrl")
    public suspend fun headers(values: List<Output<String>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("wdlwekyydtxmijkm")
    public suspend fun maxAge(`value`: Output<Int>) {
        this.maxAge = value
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("eswatwdwjtnhhmvq")
    public suspend fun methods(`value`: Output<List<String>>) {
        this.methods = value
    }

    @JvmName("lncldvdvigeqbmua")
    public suspend fun methods(vararg values: Output<String>) {
        this.methods = Output.all(values.asList())
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("acpohvaxwqpgchjo")
    public suspend fun methods(values: List<Output<String>>) {
        this.methods = Output.all(values)
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("dlciaviifyotavah")
    public suspend fun origins(`value`: Output<List<String>>) {
        this.origins = value
    }

    @JvmName("ctohpwymddfestmn")
    public suspend fun origins(vararg values: Output<String>) {
        this.origins = Output.all(values.asList())
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("eahqaloqrawoxuig")
    public suspend fun origins(values: List<Output<String>>) {
        this.origins = Output.all(values)
    }

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("gjjabkfafaskhtmq")
    public suspend fun allowCredentials(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowCredentials = mapped
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("oxclmhmvbhhsqhdk")
    public suspend fun headers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("eblnjqkketewxofy")
    public suspend fun headers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("neluecyikbwbcwou")
    public suspend fun maxAge(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxAge = mapped
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("siukbwxhtdajoqxe")
    public suspend fun methods(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("qogqpdeesspeexdt")
    public suspend fun methods(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("mdnsfracwhamgtuk")
    public suspend fun origins(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("pvldcqnffpbcjafl")
    public suspend fun origins(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    internal fun build(): FhirServiceCorsConfigurationArgs = FhirServiceCorsConfigurationArgs(
        allowCredentials = allowCredentials,
        headers = headers,
        maxAge = maxAge,
        methods = methods,
        origins = origins,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/FhirServiceCorsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The settings for the CORS configuration of the service instance.
 * @property allowCredentials If credentials are allowed via CORS.
 * @property headers The headers to be allowed via CORS.
 * @property maxAge The max age to be allowed via CORS.
 * @property methods The methods to be allowed via CORS.
 * @property origins The origins to be allowed via CORS.
 */
public data class FhirServiceCorsConfigurationArgs(
    public val allowCredentials: Output<Boolean>? = null,
    public val headers: Output<List<String>>? = null,
    public val maxAge: Output<Int>? = null,
    public val methods: Output<List<String>>? = null,
    public val origins: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs.builder()
            .allowCredentials(allowCredentials?.applyValue({ args0 -> args0 }))
            .headers(headers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .maxAge(maxAge?.applyValue({ args0 -> args0 }))
            .methods(methods?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .origins(origins?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FhirServiceCorsConfigurationArgs].
 */
@PulumiTagMarker
public class FhirServiceCorsConfigurationArgsBuilder internal constructor() {
    private var allowCredentials: Output<Boolean>? = null

    private var headers: Output<List<String>>? = null

    private var maxAge: Output<Int>? = null

    private var methods: Output<List<String>>? = null

    private var origins: Output<List<String>>? = null

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("umeombxtdnjoxhyr")
    public suspend fun allowCredentials(`value`: Output<Boolean>) {
        this.allowCredentials = value
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("mffavtvqpjcodhri")
    public suspend fun headers(`value`: Output<List<String>>) {
        this.headers = value
    }

    @JvmName("vmreeanywcjescms")
    public suspend fun headers(vararg values: Output<String>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("wbjrunaeloflunlu")
    public suspend fun headers(values: List<Output<String>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("yeuodfdwteivjcwt")
    public suspend fun maxAge(`value`: Output<Int>) {
        this.maxAge = value
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("ckqvqftdfbrkjrsg")
    public suspend fun methods(`value`: Output<List<String>>) {
        this.methods = value
    }

    @JvmName("ifykbuocexwueatv")
    public suspend fun methods(vararg values: Output<String>) {
        this.methods = Output.all(values.asList())
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("vdpcltyhbdheqgff")
    public suspend fun methods(values: List<Output<String>>) {
        this.methods = Output.all(values)
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("frvskhveblnarysb")
    public suspend fun origins(`value`: Output<List<String>>) {
        this.origins = value
    }

    @JvmName("jyanijkjgnpfogia")
    public suspend fun origins(vararg values: Output<String>) {
        this.origins = Output.all(values.asList())
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("xdwpsargdeaepkhp")
    public suspend fun origins(values: List<Output<String>>) {
        this.origins = Output.all(values)
    }

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("celtadoywxbcegsj")
    public suspend fun allowCredentials(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowCredentials = mapped
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("ikrfiodnniyhtksq")
    public suspend fun headers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("ixjfppbhlygjvjeo")
    public suspend fun headers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("ereacubdcicpqebj")
    public suspend fun maxAge(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxAge = mapped
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("tohpcqnfqprlctkv")
    public suspend fun methods(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("amwkyxexjlhkbuaf")
    public suspend fun methods(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("yakaglaxuygaddbv")
    public suspend fun origins(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("kpckeicwnmbuoxcx")
    public suspend fun origins(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    internal fun build(): FhirServiceCorsConfigurationArgs = FhirServiceCorsConfigurationArgs(
        allowCredentials = allowCredentials,
        headers = headers,
        maxAge = maxAge,
        methods = methods,
        origins = origins,
    )
}
